@@ -1,9 +1,13 @@
 """
-Top-level object for PiCloud
+Top-level object for Science VM
 Manages caching and client-side type checking
 """
 from __future__ import with_statement
 """
+Copyright (c) 2014 `Science Automation Inc. <http://www.scivm.com>`_.  All rights reserved.
+
+email: support@scivm.com
+
 Copyright (c) 2011 `PiCloud, Inc. <http://www.picloud.com>`_.  All rights reserved.
 
 email: contact@picloud.com
