@@ -8,9 +8,13 @@ The goals of it follow:
 
 It does not include an unpickler, as standard python unpickling suffices
 
+Copyright (c) 2014 `Science Automation Inc. <http://www.scivm.com>`_.  All rights reserved.
+
+email: support@scivm.com
+
 Copyright (c) 2009-2012 `PiCloud, Inc. <http://www.picloud.com>`_.  All rights reserved.
 
-email: contact@picloud.com
+email: contact@piloud.com
 
 The cloud package is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
