@@ -1,6 +1,10 @@
 """
-PiCloud network connections
-This module manages communication with the PiCloud server
+Science VM network connections
+This module manages communication with the Science VM server
+
+Copyright (c) 2014 `Science Automation Inc. <http://www.scivm.com>`_.  All rights reserved.
+
+email: support@scivm.com
 
 Copyright (c) 2010 `PiCloud, Inc. <http://www.picloud.com>`_.  All rights reserved.
 
